Learn R Programming

preventr (version 0.11.0)

app: Navigate to browser-based Shiny implementation of PREVENT equations

Description

This function opens a browser window (using the user's default browser) and navigates to the Shiny app located at:

https://martingmayer.shinyapps.io/prevent-equations

Easier-to-remember URLs:

The app includes risk visualization and several options for customizing the output.

Usage

app(...)

Value

Returns NULL invisibly after opening app in your default browser.

Arguments

...

Not used. Reserved for future use.

Examples

Run this code
app()
 

Run the code above in your browser using DataLab